@@ -1,11 +1,10 @@
 import Algorithmia
 import os
-from Algorithmia.errors import DataApiError
+from Algorithmia.errors import DataApiError, AlgorithmException
 from Algorithmia.algo_response import AlgoResponse
 import json, re, requests, six
 import toml
 import shutil
-from time import time
 
 class CLI:
     def __init__(self):
@@ -309,12 +308,10 @@ class CLI:
         return table
 
     def getBuildLogs(self, user, algo, client):
-        api_response = client.algo(user + '/' + algo).build_logs()
-
-        if "error" in api_response:
-            return json.dumps(api_response)
+        api_response = client.algo(user + '/' + algo).get_builds()
         return json.dumps(api_response['results'], indent=1)
 
+
     def getconfigfile(self):
         if (os.name == "posix"):
             # if!windows
